
    array = [random.random() for _ in range(n)]
=》
  array = random.random()_range(n)

        更小 = list(filter(lambda x: x < 头, 尾))
=》
    更小 = list(filter(x(x < 头), 尾))

对比原始可执行：

```python
array = [random.random() for _ in range(n)]

a = list(filter(lambda x: x<head, tail))
```
=>
```
array = func() { __ = []; __.append(random.random())  for _ in range(n); return __ }()

a = list(filter((x) -> (x < head), tail))
```